@@ -13,7 +13,5 @@ except ImportError:
                 "You can change that by running 'pip install transparentpath[json]'."
             )
 
-try:
-    from ._version import __version__
-except ImportError:
-    pass
+from . import _version
+__version__ = _version.get_versions()['version']
